==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-german.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Senden");
define("_URL","URL");
define("_PRINTER","Druckbare Version");
define("_FRIEND","Diesen Artikel an einen Freund senden");



define("_YOURNAME","Dein Name");

define("_OK","Ok!");
define("_RELATED","Verwandte Links");
define("_MOREABOUT","Mehr zu dem Thema");
define("_NEWSBY","Nachrichten von");
define("_MOSTREAD","Der meistgelesene Artikel zu dem Thema");
define("_READMORE","mehr...");
define("_BYTESMORE","mehr Zeichen");
define("_COMMENTSQ","Kommentare?");
define("_COMMENT","Kommentar");

define("_CONFIGURE","Konfigurieren");
define("_LOGINCREATE","Anmelden/Neuanmeldung");
define("_THRESHOLD","Grenze");
define("_NOCOMMENTS","kein Kommentar");
define("_NESTED","geschachtelt");
define("_FLAT","flach");
define("_THREAD","Diskussionsfaden");
define("_OLDEST","Alte zuerst");
define("_NEWEST","Neue zuerst");
define("_HIGHEST","H&ouml;chste Punktzahl zuerst");
define("_COMMENTSWARNING","F&uuml;r den Inhalt der Kommentare sind die Verfasser verantwortlich.");
define("_SCORE","Punkte:");


define("_USERINFO","Userinfo");
define("_READREST","Den Rest des Kommentars lesen...");
define("_REPLY","Darauf antworten");
define("_REPLYMAIN","Kommentar schreiben");
define("_NOSUBJECT","Kein Betreff");
define("_NOANONCOMMENTS","Keine anonymen Kommentare m&ouml;glich, bitte zuerst <a href=\"modules.php?name=Your_Account\">anmelden</a>");
define("_PARENT","aufw&auml;rts");
define("_ROOT","Hauptverzeichnis");

define("_UCOMMENT","Kommentar");
define("_ALLOWEDHTML","erlaubter HTML Code:");
define("_POSTANON","Anonym schreiben");
define("_EXTRANS","HTML Code zu Text umwandeln");
define("_HTMLFORMATED","HTML formatiert");
define("_PLAINTEXT","einfacher Text");
define("_ONN","auf...");
define("_SUBJECT","Betreff");
define("_COMMENTREPLY","Artikel kommentieren");
define("_COMREPLYPRE","Kommentar- Voransicht");
define("_NOTRIGHT","Die &Uuml;bergabe einer Variable an diese Funktion ist fehlerhaft. Diese Meldung soll helfen, Folgefehler zu vermeiden.");
define("_SENDAMSG","Artikel schicken");
define("_YOUSENDSTORY","Du versendest diesen Artikel an");
define("_TOAFRIEND","Deinen Freund mit dem Namen:");
define("_FYOURNAME","Dein Name:");
define("_FYOUREMAIL","Deine E-mail:");
define("_FFRIENDNAME","Name des Freundes:");
define("_FFRIENDEMAIL","eMail Adresse des Freundes:");
define("_INTERESTING","Ein interessanter Artikel bei");
define("_HELLO","Hallo");
define("_YOURFRIEND","Ihr Freund");
define("_CONSIDERED","fand den folgenden Artikel interessant und wollte ihn an Sie schicken.");
define("_FDATE","Datum:");
define("_FTOPIC","Thema:");
define("_YOUCANREAD","Hier k&ouml;nnen Sie weitere interessante Artikel lesen:");
define("_FSTORY","Artikel");
define("_HASSENT","wurde gesendet an");
define("_THANKS","Danke!");
define("_RECOMMEND","Diese Website einem Freund empfehlen");
define("_PDATE","Datum:");
define("_PTOPIC","Thema:");
define("_COMESFROM","Dieser Artikel kommt von");
define("_THEURL","Die URL f&uuml;r diesen Artikel ist:");





define("_PREVIEW","Vorschau");
define("_NEWUSER","neuer Benutzer");
define("_OPTIONS","Einstellungen");


define("_REFRESH","Aktualisieren");
define("_ADD","Hinzuf&uuml;gen");
define("_NOCOMMENTSACT","Sorry, kein Kommentar f&uuml;r diesen Artikel vorhanden.");
define("_ARTICLEPOLL","Bewertung f&uuml;r Artikel");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-german.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Senden");
define("_URL","URL");
define("_PRINTER","Druckbare Version");
define("_FRIEND","Diesen Artikel an einen Freund senden");



define("_YOURNAME","Dein Name");

define("_OK","Ok!");
define("_RELATED","Verwandte Links");
define("_MOREABOUT","Mehr zu dem Thema");
define("_NEWSBY","Nachrichten von");
define("_MOSTREAD","Der meistgelesene Artikel zu dem Thema");
define("_READMORE","mehr...");
define("_BYTESMORE","mehr Zeichen");
define("_COMMENTSQ","Kommentare?");
define("_COMMENT","Kommentar");

define("_CONFIGURE","Konfigurieren");
define("_LOGINCREATE","Anmelden/Neuanmeldung");
define("_THRESHOLD","Grenze");
define("_NOCOMMENTS","kein Kommentar");
define("_NESTED","geschachtelt");
define("_FLAT","flach");
define("_THREAD","Diskussionsfaden");
define("_OLDEST","Alte zuerst");
define("_NEWEST","Neue zuerst");
define("_HIGHEST","H&ouml;chste Punktzahl zuerst");
define("_COMMENTSWARNING","F&uuml;r den Inhalt der Kommentare sind die Verfasser verantwortlich.");
define("_SCORE","Punkte:");


define("_USERINFO","Userinfo");
define("_READREST","Den Rest des Kommentars lesen...");
define("_REPLY","Darauf antworten");
define("_REPLYMAIN","Kommentar schreiben");
define("_NOSUBJECT","Kein Betreff");
define("_NOANONCOMMENTS","Keine anonymen Kommentare m&ouml;glich, bitte zuerst <a href=\"modules.php?name=Your_Account\">anmelden</a>");
define("_PARENT","aufw&auml;rts");
define("_ROOT","Hauptverzeichnis");

define("_UCOMMENT","Kommentar");
define("_ALLOWEDHTML","erlaubter HTML Code:");
define("_POSTANON","Anonym schreiben");
define("_EXTRANS","HTML Code zu Text umwandeln");
define("_HTMLFORMATED","HTML formatiert");
define("_PLAINTEXT","einfacher Text");
define("_ONN","auf...");
define("_SUBJECT","Betreff");
define("_COMMENTREPLY","Artikel kommentieren");
define("_COMREPLYPRE","Kommentar- Voransicht");
define("_NOTRIGHT","Die &Uuml;bergabe einer Variable an diese Funktion ist fehlerhaft. Diese Meldung soll helfen, Folgefehler zu vermeiden.");
define("_SENDAMSG","Artikel schicken");
define("_YOUSENDSTORY","Du versendest diesen Artikel an");
define("_TOAFRIEND","Deinen Freund mit dem Namen:");
define("_FYOURNAME","Dein Name:");
define("_FYOUREMAIL","Deine E-mail:");
define("_FFRIENDNAME","Name des Freundes:");
define("_FFRIENDEMAIL","eMail Adresse des Freundes:");
define("_INTERESTING","Ein interessanter Artikel bei");
define("_HELLO","Hallo");
define("_YOURFRIEND","Ihr Freund");
define("_CONSIDERED","fand den folgenden Artikel interessant und wollte ihn an Sie schicken.");
define("_FDATE","Datum:");
define("_FTOPIC","Thema:");
define("_YOUCANREAD","Hier k&ouml;nnen Sie weitere interessante Artikel lesen:");
define("_FSTORY","Artikel");
define("_HASSENT","wurde gesendet an");
define("_THANKS","Danke!");
define("_RECOMMEND","Diese Website einem Freund empfehlen");
define("_PDATE","Datum:");
define("_PTOPIC","Thema:");
define("_COMESFROM","Dieser Artikel kommt von");
define("_THEURL","Die URL f&uuml;r diesen Artikel ist:");





define("_PREVIEW","Vorschau");
define("_NEWUSER","neuer Benutzer");
define("_OPTIONS","Einstellungen");


define("_REFRESH","Aktualisieren");
define("_ADD","Hinzuf&uuml;gen");
define("_NOCOMMENTSACT","Sorry, kein Kommentar f&uuml;r diesen Artikel vorhanden.");
define("_ARTICLEPOLL","Bewertung f&uuml;r Artikel");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
